using System;
using System.Reflection;
using System.Collections;
using System.ComponentModel;
using System.Drawing;
using System.Drawing.Drawing2D;

namespace UMD.HCIL {
	public enum ButtonState {Normal, Checked, Pushed};
	public enum ScrollButton {Down, Left, Max, Min, Right, Up}

	public class ControlPaint {
		static Pen blackPen = new Pen(Color.Black);
		static Pen whitePen = new Pen(Color.White);
		static Pen lightGrayPen = new Pen(SystemColors.Control);
		static Pen mediumGrayPen = new Pen(Color.FromArgb(150, 150, 150));
		static Pen darkGrayPen = new Pen(Color.FromArgb(100, 100, 100));
		static Brush blackBrush = new SolidBrush(Color.Black);
		static Brush whiteBrush = new SolidBrush(Color.White);
		static Brush lightGrayBrush = new SolidBrush(SystemColors.Control);
		//		static Image checkedboxImage = new Bitmap(Assembly.GetExecutingAssembly().GetManifestResourceStream("DateLens.Images.check.bmp"));
		//		static Image uncheckedboxImage = new Bitmap(Assembly.GetExecutingAssembly().GetManifestResourceStream("DateLens.Images.unchecked.bmp"));

		static public void DrawButton(Graphics g, int x, int y, int width, int height, ButtonState state, bool transparent) {
			if (!transparent) g.FillRectangle(lightGrayBrush, x, y, width, height);

			if (state == ButtonState.Normal) {
				g.DrawLine(whitePen, x, y, x + width - 1, y);
				g.DrawLine(whitePen, x, y, x, y + height - 1);
				g.DrawLine(darkGrayPen, x + width - 1, y, x + width - 1, y + height - 1);
				g.DrawLine(darkGrayPen, x, y + height - 1, x + width - 1, y + height - 1);
				g.DrawLine(mediumGrayPen, x + width - 2, y + 1, x + width - 2, y + height - 3);
				g.DrawLine(mediumGrayPen, x + 1, y + height - 2, x + width - 2, y + height - 2);
			}
			else if (state == ButtonState.Pushed) {
				g.DrawLine(darkGrayPen, x, y, x + width - 1, y);
				g.DrawLine(darkGrayPen, x, y, x, y + height - 1);
				g.DrawLine(whitePen, x + width - 1, y, x + width - 1, y + height - 1);
				g.DrawLine(whitePen, x, y + height - 1, x + width - 1, y + height - 1);
				g.DrawLine(mediumGrayPen, x + 1, y + 1, x + 1, y + height - 3);
				g.DrawLine(mediumGrayPen, x + 1, y + 1, x + width - 2, y + 1);
			}
		}

		static public void DrawScrollButton(Graphics g, int x, int y, int width, int height, ScrollButton button, ButtonState state, bool transparent) {
			if (!transparent) g.FillRectangle(lightGrayBrush, x, y, width, height);

			if (state == ButtonState.Normal) {
				g.DrawLine(whitePen, x, y, x + width - 1, y);
				g.DrawLine(whitePen, x, y, x, y + height - 1);
				g.DrawLine(darkGrayPen, x + width - 1, y, x + width - 1, y + height - 1);
				g.DrawLine(darkGrayPen, x, y + height - 1, x + width - 1, y + height - 1);
				g.DrawLine(mediumGrayPen, x + width - 2, y + 1, x + width - 2, y + height - 3);
				g.DrawLine(mediumGrayPen, x + 1, y + height - 2, x + width - 2, y + height - 2);
			}
			else if (state == ButtonState.Pushed) {
				g.DrawLine(darkGrayPen, x, y, x + width - 1, y);
				g.DrawLine(darkGrayPen, x, y, x, y + height - 1);
				g.DrawLine(whitePen, x + width - 1, y, x + width - 1, y + height - 1);
				g.DrawLine(whitePen, x, y + height - 1, x + width - 1, y + height - 1);
				g.DrawLine(mediumGrayPen, x + 1, y + 1, x + 1, y + height - 3);
				g.DrawLine(mediumGrayPen, x + 1, y + 1, x + width - 2, y + 1);
			}

			width -= 3;
			height -= 3;
			x += 1;
			y += 1;
			int ArrowHeight = height / 3;
			int ArrowWidth = 2 * ArrowHeight;
			int xOffset = (width - ArrowWidth) / 2;
			int yOffset = (height - ArrowHeight) / 2;

			Point[] points = new Point[3];

			switch (button) {
				case ScrollButton.Down:
					points[0] = new Point(x + xOffset, y + yOffset);
					points[1] = new Point(x + xOffset + ArrowWidth, y + yOffset);
					points[2] = new Point(x + xOffset + (ArrowWidth / 2), y + yOffset + ArrowHeight);
					
					g.DrawPolygon(blackPen, points);
					g.FillPolygon(blackBrush, points);
					break;
				case ScrollButton.Left:
					break;
				case ScrollButton.Max:
					break;
				case ScrollButton.Min:
					break;
				case ScrollButton.Right:
					break;
				case ScrollButton.Up:
					points[0] = new Point(x + xOffset, y + yOffset + ArrowHeight);
					points[1] = new Point(x + xOffset + ArrowWidth, y + yOffset + ArrowHeight);
					points[2] = new Point(x + xOffset + (ArrowWidth / 2), y + yOffset);
					
					g.DrawPolygon(blackPen, points);
					g.FillPolygon(blackBrush, points);
					break;
				default: Console.WriteLine("Error: Invalid Button Type");
					break;
			}
		}
	}
}
